@@ -17,6 +17,12 @@ read.dta <- function(file, convert.dates = TRUE,
                      convert.factors = TRUE, missing.type = FALSE,
                      convert.underscore = FALSE, warn.missing.labels = TRUE)
 {
+    if(length(grep("^(http|ftp|https)://", file))) {
+        tmp <- tempfile()
+        download.file(file, tmp, quiet = TRUE, mode = "wb")
+        file <- tmp
+        on.exit(unlink(file))
+    }
     rval <- .External(do_readStata, file)
 
     if(convert.underscore)
@@ -101,10 +107,11 @@ write.dta <-
              convert.factors = c("labels","string","numeric","codes"))
 {
 
-    if (version < 6L) stop("Version must be 6-10")
+    if (version < 6L) stop("Version must be 6-11")
     if (version == 9L) version <- 8L
-    if (version > 10L) {
-        warning("Version must be 6-10: using 7")
+    if (version == 11L) version <- 10L
+    if (version > 11L) {
+        warning("Version must be 6-11: using 7")
         version <- 7L
     }
 
